self.__BUILD_MANIFEST=function(s,e,i,n,p,c,t,a,l,u,d,f,r,k,b,h,j,g,o,_,m,E,O,A,B,L,D,T,C,I){return{__rewrites:{beforeFiles:[],afterFiles:[{source:"/CLOUD_NOTEBOOK_BASE_PATH_PLACEHOLDER_/datasets",destination:j},{source:"/CLOUD_NOTEBOOK_BASE_PATH_PLACEHOLDER_",destination:j}],fallback:[]},"/":[s,i,"static/chunks/pages/index-21c7f3ddbf473bb6.js"],"/_error":["static/chunks/pages/_error-235304e5badb19eb.js"],"/datasets":[s,e,n,p,A,"static/chunks/pages/datasets-b7e0fa2d1fb3b091.js"],"/datasets/[...slug]":[g,s,e,n,u,f,r,o,B,"static/chunks/8337-90ab148af0d8bbab.js",p,t,a,k,_,L,A,"static/chunks/pages/datasets/[...slug]-410d34dd6419d35d.js"],"/manage":[s,e,n,i,p,c,a,"static/chunks/pages/manage-4c8e37fac4d8abd4.js"],"/pipeline-runs":[s,e,n,i,p,c,a,m,"static/chunks/pages/pipeline-runs-09a048846bd4d2d5.js"],"/pipelines":[s,e,n,i,p,c,"static/chunks/pages/pipelines-7e41eb1cf0cd9317.js"],"/pipelines/[pipeline]":["static/chunks/pages/pipelines/[pipeline]-0c6dc5356df3d124.js"],"/pipelines/[pipeline]/edit":[g,s,e,n,u,d,f,b,r,E,o,O,B,D,i,p,c,t,a,k,h,_,L,T,"static/chunks/pages/pipelines/[pipeline]/edit-f5cbafdafb028675.js"],"/pipelines/[pipeline]/logs":[s,e,n,d,O,C,i,p,c,t,l,a,"static/chunks/pages/pipelines/[pipeline]/logs-9e731f98bcdf137b.js"],"/pipelines/[pipeline]/monitors":[s,e,n,u,r,i,p,c,t,l,I,"static/chunks/pages/pipelines/[pipeline]/monitors-00ea20e16b43e3c0.js"],"/pipelines/[pipeline]/monitors/block-runs":[s,e,n,u,r,i,p,c,t,l,a,I,"static/chunks/pages/pipelines/[pipeline]/monitors/block-runs-662f5c984039bca4.js"],"/pipelines/[pipeline]/monitors/block-runtime":[g,s,e,n,u,r,"static/chunks/9832-c8b8970bb522f302.js",i,p,c,t,l,a,_,"static/chunks/pages/pipelines/[pipeline]/monitors/block-runtime-749c56e95c60328f.js"],"/pipelines/[pipeline]/runs":[s,e,n,d,b,E,i,p,c,t,l,a,h,m,"static/chunks/pages/pipelines/[pipeline]/runs-50f69cf02203a532.js"],"/pipelines/[pipeline]/runs/[run]":[s,e,n,u,d,f,b,o,i,p,c,t,l,k,h,"static/chunks/pages/pipelines/[pipeline]/runs/[run]-184ae8bf4b04f599.js"],"/pipelines/[pipeline]/syncs":[s,e,n,i,p,c,t,l,"static/chunks/pages/pipelines/[pipeline]/syncs-f5a9227ba8849d95.js"],"/pipelines/[pipeline]/triggers":[s,e,n,u,d,f,b,i,p,c,t,l,k,h,"static/chunks/pages/pipelines/[pipeline]/triggers-dba95adb1dde02a8.js"],"/pipelines/[pipeline]/triggers/[...slug]":[s,e,n,u,d,f,b,E,C,i,p,c,t,l,a,k,h,m,T,"static/chunks/pages/pipelines/[pipeline]/triggers/[...slug]-f1cea40b1b6494de.js"],"/terminal":[s,e,O,D,i,"static/chunks/pages/terminal-81714589c712f36f.js"],sortedPages:["/","/_app","/_error",j,"/datasets/[...slug]","/manage","/pipeline-runs","/pipelines","/pipelines/[pipeline]","/pipelines/[pipeline]/edit","/pipelines/[pipeline]/logs","/pipelines/[pipeline]/monitors","/pipelines/[pipeline]/monitors/block-runs","/pipelines/[pipeline]/monitors/block-runtime","/pipelines/[pipeline]/runs","/pipelines/[pipeline]/runs/[run]","/pipelines/[pipeline]/syncs","/pipelines/[pipeline]/triggers","/pipelines/[pipeline]/triggers/[...slug]","/terminal"]}}("static/chunks/4259-f723eee7c5c19f8e.js","static/chunks/2212-f7752030be6ab268.js","static/chunks/1374-aba9a59280f0ef4f.js","static/chunks/7689-00c30d501386404b.js","static/chunks/5763-1439695af490a43a.js","static/chunks/6792-54f1f01e09b7389b.js","static/chunks/1273-f481b15634dea30c.js","static/chunks/9898-e0cdd84c40455727.js","static/chunks/8965-ea2c425f4518f61b.js","static/chunks/6674-1079b372f27125d6.js","static/chunks/4804-01a10103ebe26ca8.js","static/chunks/5872-103815a4a043489b.js","static/chunks/2714-1e79e9f2e998b544.js","static/chunks/2151-eed54f54308168fa.js","static/chunks/1774-aa51ef1da7217ff9.js","static/chunks/5703-8cde054889bd5a7e.js","/datasets","static/chunks/29107295-989a0767a635d9d5.js","static/chunks/2125-0b537dc53fe71b18.js","static/chunks/3461-9983660d1aa26245.js","static/chunks/4846-c4ed8d380344c668.js","static/chunks/2524-6aeb9419acf5d1b4.js","static/chunks/9565-28e1c30511c95c2d.js","static/chunks/3887-119c1fabb9a6673a.js","static/chunks/8601-1c68fd5b5c0acd77.js","static/chunks/4835-1df0b8749b671160.js","static/chunks/6085-692d2f784c0504f2.js","static/chunks/7788-60e0a755aed9ef9f.js","static/chunks/4495-4f0340aa82e0c623.js","static/chunks/7400-0b68e5a8d4074e2b.js"),self.__BUILD_MANIFEST_CB&&self.__BUILD_MANIFEST_CB();